pub struct FeaturedTag {
pub id: String,
pub name: String,
pub url: String,
pub statuses_count: u64,
pub last_status_at: String,
}Expand description
Represents a tag that is featured on a user’s profile.
Fields
id: StringThe internal ID of the featured tag.
name: StringThe name of the tag.
url: StringThe URL to the tag’s page on the instance.
statuses_count: u64The number of statuses posted with this tag.
last_status_at: StringThe time of the last status posted with this tag (ISO 8601).